function K = getKernelParam(theta,method,weights)
%--------------------------------------------------------------------------
% Computes global parameter of the dirichlet kernel
%
% Inputs:       theta (Dirichlet variates)
%
% Outputs:      K (kernel param)
%--------------------- Pedro Saa 2016 -------------------------------------
D = size(theta,2);
switch method
    case 1						 % Pseudo concentration parameter of the MLE estimate
        options  = optimset('TolX',1e-10,'TolFun',1e-8,'MaxIter',1e4,'MaxFunEvals',1e4,'Display','off');
        alpha0   = ones(1,D);
        alphaMLE = exp(fminsearch(@probDirichlet,log(alpha0),options,theta,3,weights'));                        % Compute weighted-MLE for alpha
        K        = sum(alphaMLE)-D;
    case 2                      % Weighted total variance
        Var = zeros(D);
        for ix = 1:D
            for jx = 1:D
                if (ix~=jx)
                    Var(ix,jx) = var(log(theta(:,ix)./theta(:,jx)),weights);
                end
            end
        end
        K = 2*D/sum(Var(:));
    case 3					     % Weighted generalized variance
        Var = zeros(D);
        for ix = 1:D
            for jx = 1:D
                if (ix~=jx)
                    Var(ix,jx) = var(log(theta(:,ix)./theta(:,jx)),weights);
                end
            end
        end
        K = abs(1/det(Var));
end